==> nipper-0.10.4.tgz: nipper-0.10.4/PIX/process-general.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


struct namePIXList
{
	char address[16];
	char name[64];
	struct namePIXList *next;
};

// Process Domain Loopup
void processPIXName(char *line, struct nipperConfig *nipper)
{
	// Variables...
	struct namePIXList *namePIXPointer;
	struct ciscoCommand command;

	// Debug output
	if (nipper->debugMode == true)
		printf("Name Line: %s\n", line);
	
	// Is first entry?
	if (nipper->pix->nameList == 0)
	{
		nipper->pix->nameList = malloc(sizeof(struct namePIXList));
		namePIXPointer = nipper->pix->nameList;
	}
	else
	{
		namePIXPointer = nipper->pix->nameList;
		while (namePIXPointer->next != 0)
			namePIXPointer = namePIXPointer->next;
		namePIXPointer->next = malloc(sizeof(struct namePIXList));
		namePIXPointer = namePIXPointer->next;
	}

	// Init
	memset(namePIXPointer, 0, sizeof(struct namePIXList));
	command = splitLine(line);

	// Address
	strncpy(namePIXPointer->address, command.part[1], sizeof(namePIXPointer->address) - 1);

	// Name
	strncpy(namePIXPointer->name, command.part[2], sizeof(namePIXPointer->name) - 2);
}

==> nipper-0.10.5.tgz: nipper-0.10.5/PIX/process-general.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


struct namePIXList
{
	char address[16];
	char name[64];
	struct namePIXList *next;
};

// Process Domain Loopup
void processPIXName(char *line, struct nipperConfig *nipper)
{
	// Variables...
	struct namePIXList *namePIXPointer = 0;
	struct ciscoCommand command;

	// Debug output
	if (nipper->debugMode == true)
		printf("Name Line: %s\n", line);
	
	// Is first entry?
	if (nipper->pix->nameList == 0)
	{
		nipper->pix->nameList = malloc(sizeof(struct namePIXList));
		namePIXPointer = nipper->pix->nameList;
	}
	else
	{
		namePIXPointer = nipper->pix->nameList;
		while (namePIXPointer->next != 0)
			namePIXPointer = namePIXPointer->next;
		namePIXPointer->next = malloc(sizeof(struct namePIXList));
		namePIXPointer = namePIXPointer->next;
	}

	// Init
	memset(namePIXPointer, 0, sizeof(struct namePIXList));
	command = splitLine(line);

	// Address
	strncpy(namePIXPointer->address, command.part[1], sizeof(namePIXPointer->address) - 1);

	// Name
	strncpy(namePIXPointer->name, command.part[2], sizeof(namePIXPointer->name) - 2);
}
